@@ -9,7 +9,8 @@ from typing import IO, Dict, FrozenSet, Generator, List, Optional, Union
 import git
 from pydantic import BaseModel, parse_obj_as, validator
 
-from gto.base import BaseManager, BaseRegistryState, BaseVersion
+from gto.base import BaseManager, BaseRegistryState
+from gto.base import Commit as EnrichmentEvent
 from gto.config import (
     CONFIG_FILE_NAME,
     RegistryConfig,
@@ -26,7 +27,7 @@ from gto.exceptions import (
     PathIsUsed,
     WrongArgs,
 )
-from gto.ext import Enrichment, EnrichmentInfo
+from gto.ext import EnrichmentInfo, EnrichmentReader
 from gto.utils import resolve_ref
 
 
@@ -95,6 +96,8 @@ class Index(BaseModel):
             assert_name_is_valid(name)
             if artifact.type:
                 assert_name_is_valid(artifact.type)
+            for label in artifact.labels:
+                assert_name_is_valid(label)
         return v
 
     def __contains__(self, item):
@@ -180,6 +183,8 @@ class BaseIndexManager(BaseModel, ABC):
         raise NotImplementedError
 
     def add(self, name, type, path, must_exist, labels, description, update):
+        for arg in [name] + list(labels or []):
+            assert_name_is_valid(arg)
         if type:
             self.config.assert_type(type)
         if must_exist:
@@ -351,13 +356,25 @@ class EnrichmentManager(BaseManager):
         # processing registered artifacts and versions first
         for artifact in state.get_artifacts().values():
             for version in artifact.versions:
+                commit = self.repo.commit(version.commit_hexsha)
                 enrichments = self.describe(
-                    artifact.name,
+                    artifact.artifact,
                     # faster to make git.Reference here
-                    rev=self.repo.commit(version.commit_hexsha),
+                    rev=commit,
                 )
-                artifact.update_enrichments(
-                    version=version.name, enrichments=enrichments
+                version.add_event(
+                    EnrichmentEvent(
+                        artifact=artifact.artifact,
+                        version=version.version,
+                        created_at=datetime.fromtimestamp(commit.committed_date),
+                        author=commit.author.name,
+                        author_email=commit.author.email,
+                        commit_hexsha=commit.hexsha,
+                        message=commit.message,
+                        committer=commit.committer.name,
+                        committer_email=commit.committer.email,
+                        enrichments=enrichments,
+                    )
                 )
                 state.update_artifact(artifact)
         for commit in self.get_commits(
@@ -366,31 +383,26 @@ class EnrichmentManager(BaseManager):
             for art_name in GTOEnrichment().discover(self.repo, commit):
                 enrichments = self.describe(art_name, rev=commit)
                 artifact = state.find_artifact(art_name, create_new=True)
-                version = artifact.find_version(commit_hexsha=commit.hexsha)
-                # TODO: duplicated in tag.py
-                if version:
-                    version = version.name
-                else:
-                    artifact.add_version(
-                        BaseVersion(
-                            artifact=art_name,
-                            name=commit.hexsha,
-                            created_at=datetime.fromtimestamp(commit.committed_date),
-                            author=commit.author.name,
-                            author_email=commit.author.email,
-                            commit_hexsha=commit.hexsha,
-                            discovered=True,
-                        )
+                version = artifact.find_version(
+                    commit_hexsha=commit.hexsha, create_new=True
+                )
+                version.add_event(
+                    EnrichmentEvent(
+                        artifact=artifact.artifact,
+                        version=version.version,
+                        created_at=datetime.fromtimestamp(commit.committed_date),
+                        author=commit.author.name,
+                        author_email=commit.author.email,
+                        commit_hexsha=commit.hexsha,
+                        message=commit.message,
+                        committer=commit.committer.name,
+                        committer_email=commit.committer.email,
+                        enrichments=enrichments,
                     )
-                    version = commit.hexsha
-                artifact.update_enrichments(version=version, enrichments=enrichments)
+                )
                 state.update_artifact(artifact)
         return state
 
-    def check_ref(self, ref: str, state: BaseRegistryState):
-        # TODO: implement
-        raise NotImplementedError()
-
 
 def init_index_manager(path):
     try:
@@ -413,7 +425,7 @@ class GTOInfo(EnrichmentInfo):
         return self.artifact.path
 
 
-class GTOEnrichment(Enrichment):
+class GTOEnrichment(EnrichmentReader):
     source = "gto"
 
     def discover(  # pylint: disable=no-self-use
