@@ -102,34 +102,34 @@ EXPECTED_DESCRIBE_OUTPUT = """{
 def test_commands(showcase):
     path, repo, write_file, first_commit, second_commit = showcase
     _check_successful_cmd(
-        "latest",
-        ["-r", path, "rf"],
+        "show",
+        ["-r", path, "rf@greatest", "--version"],
         "v1.2.4\n",
     )
     _check_successful_cmd(
-        "latest",
-        ["-r", path, "rf", "--ref"],
+        "show",
+        ["-r", path, "rf@greatest", "--ref"],
         "rf@v1.2.4\n",
     )
     _check_successful_cmd(
-        "which",
-        ["-r", path, "rf", "production"],
-        "v1.2.4\n",
+        "show",
+        ["-r", path, "rf#production", "--version"],
+        "v1.2.3\n",
     )
     _check_successful_cmd(
-        "which",
-        ["-r", path, "rf", "production", "--vs", "-1"],
+        "show",
+        ["-r", path, "rf#production", "--vs", "-1", "--version"],
         "v1.2.4\nv1.2.3\n",
     )
     _check_successful_cmd(
-        "which",
-        ["-r", path, "rf", "staging", "--vs", "-1"],
+        "show",
+        ["-r", path, "rf#staging", "--vs", "-1", "--version"],
         "v1.2.4\n",
     )
     _check_successful_cmd(
-        "which",
-        ["-r", path, "rf", "production", "--ref"],
-        "rf#production#3\n",
+        "show",
+        ["-r", path, "rf#production", "--ref"],
+        "rf@v1.2.3\n",
     )
     _check_successful_cmd("describe", ["-r", path, "rf"], EXPECTED_DESCRIBE_OUTPUT)
     _check_successful_cmd(
@@ -293,6 +293,22 @@ def test_register(repo_with_commit: Tuple[git.Repo, Callable]):
         "    git push a2@v1.2.3\n",
     )
 
+    _check_successful_cmd(
+        "deprecate",
+        ["-r", repo.working_dir, "a2", "v1.2.3"],
+        "Created git tag 'a2@v1.2.3!' that deregisters version\n"
+        "To push the changes upstream, run:\n"
+        "    git push a2@v1.2.3!\n",
+    )
+
+    _check_successful_cmd(
+        "register",
+        ["-r", repo.working_dir, "a2", "--simple", "false"],
+        "Created git tag 'a2@v1.2.3#1' that registers version\n"
+        "To push the changes upstream, run:\n"
+        "    git push a2@v1.2.3#1\n",
+    )
+
     _check_failing_cmd(
         "register",
         ["-r", repo.working_dir, "a3", "--version", "1.2.3"],
@@ -313,7 +329,7 @@ def test_assign(repo_with_commit: Tuple[git.Repo, Callable]):
     # this check depends on the previous one
     _check_successful_cmd(
         "assign",
-        ["-r", repo.working_dir, "nn1", "prod", "HEAD"],
+        ["-r", repo.working_dir, "nn1", "HEAD", "--stage", "prod"],
         "Created git tag 'nn1#prod#1' that assigns stage to version 'v0.0.1'\n"
         "To push the changes upstream, run:\n"
         "    git push nn1#prod#1\n",
@@ -321,12 +337,30 @@ def test_assign(repo_with_commit: Tuple[git.Repo, Callable]):
     # this check depends on the previous assignment
     _check_failing_cmd(
         "assign",
-        ["-r", repo.working_dir, "nn1", "stage", "HEAD", "--version", "v1.0.0"],
+        [
+            "-r",
+            repo.working_dir,
+            "nn1",
+            "HEAD",
+            "--version",
+            "v1.0.0",
+            "--stage",
+            "stage",
+        ],
         "❌ Can't register 'v1.0.0', since 'v0.0.1' is registered already at this ref\n",
     )
 
     _check_failing_cmd(
         "assign",
-        ["-r", repo.working_dir, "nn2", "prod", "HEAD", "--version", "1.0.0"],
+        [
+            "-r",
+            repo.working_dir,
+            "nn2",
+            "HEAD",
+            "--version",
+            "1.0.0",
+            "--stage",
+            "prod",
+        ],
         "❌ Version '1.0.0' is not valid. Example of valid version: 'v1.0.0'\n",
     )
